@@ -1,13 +1,18 @@
 from functools import partial
-from itertools import ifilter
+
+try:
+    from itertools import ifilter
+    from itertools import imap
+except ImportError:
+    imap = map
+    ifilter = filter
+
 import os
 
 from karld.iter_utils import yield_nth_of
-from karld.unicode_io import csv_reader
 
 from .loadump import ensure_dir
 from .loadump import i_get_csv_data
-from .loadump import i_read_buffered_file
 from .loadump import i_walk_dir_for_filepaths_names
 from .loadump import write_as_csv
 
@@ -19,7 +24,7 @@ def csv_file_to_file(csv_rows_consumer, out_prefix, out_dir, file_path_name):
     as a csv file into out_dir as the same name, lowered, and prefixed.
 
     :param csv_rows_consumer: consumes data_items yielding collection for each
-    :type csv_rows_consumer: function
+    :type csv_rows_consumer: callable
     :param out_prefix: prefix out_file_name
     :type out_prefix: str
     :param out_dir: directory to write output file to
@@ -29,8 +34,7 @@ def csv_file_to_file(csv_rows_consumer, out_prefix, out_dir, file_path_name):
 
     """
     data_path, data_file_name = file_path_name
-    lines = i_read_buffered_file(data_path)
-    data_items = csv_reader(lines)
+    data_items = i_get_csv_data(data_path)
     ensure_dir(out_dir)
     out_filename = os.path.join(
         out_dir, '{}{}'.format(
@@ -129,4 +133,4 @@ def serial_run_files_to_files(file_to_file, in_dir, filter_func=None):
     else:
         results_final = results
 
-    map(file_to_file, results_final)
+    list(map(file_to_file, results_final))
